# Installation

Intake-thredds can be installed from PyPI with pip:

```bash
python -m pip install intake-thredds
```

Intake-thredds is also available from conda-forge for conda installations:

```bash
conda install -c conda-forge intake-thredds
```
